@@ -4,14 +4,18 @@
 # License           : MIT license <Check LICENSE>
 # Author            : Anderson Ignacio da Silva (aignacio) <anderson@aignacio.com>
 # Date              : 06.02.2023
-# Last Modified Date: 08.04.2023
+# Last Modified Date: 10.04.2023
 import logging
 import os
 import sys
-from common.constants import options,base_module
 from tabulate import tabulate
 from jinja2 import Environment, FileSystemLoader
 from datetime import datetime
+try:
+    from ipsocgen.common.constants import options,base_module
+    from ipsocgen.common.modules import *
+except ImportError:
+    from common.constants import options,base_module
 
 class Axi4Bus(base_module):
     def __init__(self, cfg, mmap):
@@ -315,16 +319,17 @@ class Clock(base_module):
             self.clkfbout_mult = clk_cfg['pll']['clkfbout_mult']
             self.clkout_divide = clk_cfg['pll']['clkout_divide']
             self.clkin_period  = clk_cfg['pll']['clkin_period']
-            self.io_clk_MHz    = clk_cfg['io_clk_MHz']
+            self.io_in_clk     = clk_cfg['io_in_clk']
             self.clk_int       = clk_cfg['clk_int']
             self.signals.append('  logic '+self.clk_int+';')
-            self.io['in'].append(['logic', clk_cfg['io_clk_MHz']])
+            self.io['in'].append(['logic', clk_cfg['io_in_clk']])
             self.io['in'].append(['logic', clk_cfg['pll']['io_rst_pin']])
         else:
             super().__init__(clk_cfg['name'], 0, 0, options.tmpl_clk)
-            self.io_clk_MHz    = clk_cfg['io_clk_MHz']
+            self.io_in_clk     = clk_cfg['io_in_clk']
             self.clk_int       = clk_cfg['clk_int']
-            self.io['in'].append(['logic', clk_cfg['io_clk_MHz']])
+            self.signals.append('  logic '+clk_cfg['clk_int']+';')
+            self.io['in'].append(['logic', clk_cfg['io_in_clk']])
 
 class RaveNoC(base_module):
     def __init__(self, cfg, soc_common, slv_id, noc_type):
@@ -356,10 +361,9 @@ class Reset(base_module):
             self.signals.append('  logic '+rst_cfg['rst_int']+';')
 
 class ModuleHeader(base_module):
-    def __init__(self, type_cfg, name, desc, io_list, defines):
+    def __init__(self, type_cfg, name, desc, io_list):
         super().__init__(0, 0, 0, options.tmpl_module_header)
         if type_cfg == 'soc':
-            self.defines = defines
             self.name = name
             self.type = 'soc'
             for i in io_list:
@@ -370,7 +374,6 @@ class ModuleHeader(base_module):
             self.desc = desc
             self.date = datetime.now().strftime('%d/%m/%Y %H:%M:%S')
         elif type_cfg == 'mpsoc':
-            self.defines = defines
             self.name = name
             self.type = 'mpsoc'
             self.io_list = io_list
@@ -379,6 +382,15 @@ class ModuleHeader(base_module):
         else:
             logging.error('Illegal ModuleHeader type')
 
+class ModuleDefines(base_module):
+    def __init__(self, name, desc, defines):
+        super().__init__(0, 0, 0, options.tmpl_defines)
+        self.defines = defines
+        self.name = name
+        self.type = 'mpsoc'
+        self.desc = desc
+        self.date = datetime.now().strftime('%d/%m/%Y %H:%M:%S')
+
 class ModuleInstance(base_module):
     def __init__(self, module_info):
         super().__init__(0, 0, 0, options.tmpl_module_inst)
@@ -389,3 +401,31 @@ class ModuleInstance(base_module):
         self.io_rst_mpsoc   = module_info['io_rst_mpsoc']
         self.io_noc_miso    = module_info['io_noc_mosi']
         self.io_noc_mosi    = module_info['io_noc_miso']
+
+class Axi4AccEthernet(base_module):
+    def __init__(self, soc_common, eth_info):
+        super().__init__(eth_info['name'], soc_common['clk'], soc_common['rst'], options.tmpl_axi4_ethernet)
+        self.clk_ext       = soc_common['clk_ext']
+        self.desc          = eth_info['desc']
+        self.csr_slv_id    = eth_info['csr_slv_id']
+        self.inf_slv_id    = eth_info['inf_slv_id']
+        self.out_slv_id    = eth_info['out_slv_id']
+        self.pkt_recv_irq  = eth_info['pkt_recv_irq']
+        self.pkt_sent_irq  = eth_info['pkt_sent_irq']
+        self.pkt_recv_full_irq = eth_info['pkt_recv_full_irq']
+
+        self.signals.append('  logic '+self.pkt_recv_irq+';')
+        self.signals.append('  logic '+self.pkt_sent_irq+';')
+        self.signals.append('  logic '+self.pkt_recv_full_irq+';')
+        self.signals.append('  s_rgmii_tx_t phy_tx;')
+        self.signals.append('  s_rgmii_rx_t phy_rx;')
+
+        self.io['in'].append(['logic','phy_rx_clk'])
+        self.io['in'].append(['logic [3:0]','phy_rxd'])
+        self.io['in'].append(['logic','phy_rx_ctl'])
+        self.io['in'].append(['logic','phy_int_n'])
+        self.io['in'].append(['logic','phy_pme_n'])
+        self.io['out'].append(['logic','phy_tx_clk'])
+        self.io['out'].append(['logic [3:0]','phy_txd'])
+        self.io['out'].append(['logic','phy_tx_ctl'])
+        self.io['out'].append(['logic','phy_reset_n'])
